## ---- include = FALSE----------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----setup---------------------------------------------------------------
library(gradeR)

## ---- out.width = "400px", include=TRUE, fig.align="center", echo=F------
knitr::include_graphics("example/distributed_assignment/screenshot.png")

